@@ -19,6 +19,7 @@ import (
 	"fmt"
 	"io"
 	"iter"
+	"slices"
 	"strings"
 	"sync"
 	"sync/atomic"
@@ -41,7 +42,6 @@ import (
 	"github.com/gohugoio/hugo/common/hmaps"
 	"github.com/gohugoio/hugo/common/hsync"
 	"github.com/gohugoio/hugo/common/htime"
-	"github.com/gohugoio/hugo/common/hugo"
 	"github.com/gohugoio/hugo/common/loggers"
 	"github.com/gohugoio/hugo/common/para"
 	"github.com/gohugoio/hugo/common/terminal"
@@ -70,7 +70,7 @@ type HugoSites struct {
 
 	Configs *allconfig.Configs
 
-	hugoInfo hugo.HugoInfo
+	hugoInfo page.HugoInfo
 
 	// Render output formats for all sites.
 	renderFormats output.Formats
@@ -102,8 +102,13 @@ type HugoSites struct {
 	previousPageTreesWalkContext *doctree.WalkContext[contentNode]     // Set for rebuilds only.
 	previousSeenTerms            *hmaps.Map[term, sitesmatrix.Vectors] // Set for rebuilds only.
 
-	printUnusedTemplatesInit sync.Once
-	printPathWarningsInit    sync.Once
+	printUnusedTemplatesInit            sync.Once
+	printPathWarningsInit               sync.Once
+	printSiteSitesDeprecationInit       sync.Once
+	printSiteDataDeprecationInit        sync.Once
+	printSiteAllPagesDeprecationInit    sync.Once
+	printSiteBuildDraftsDeprecationInit sync.Once
+	printSiteLanguagesDeprecationInit   sync.Once
 
 	// File change events with filename stored in this map will be skipped.
 	skipRebuildForFilenamesMu sync.Mutex
@@ -122,6 +127,20 @@ type HugoSites struct {
 	buildCounter atomic.Uint64
 }
 
+// hugoSitesSitesProvider is a wrapper that implements page.SitesProvider.
+// This avoids naming conflict with HugoSites.Sites field.
+type hugoSitesSitesProvider struct {
+	h *HugoSites
+}
+
+func (sp hugoSitesSitesProvider) Sites() page.Sites {
+	return slices.Collect(sp.h.allSitesInterface(nil))
+}
+
+func (sp hugoSitesSitesProvider) Data() map[string]any {
+	return sp.h.Data()
+}
+
 type progressReporter struct {
 	mu                  sync.Mutex
 	t                   time.Time
@@ -138,12 +157,19 @@ func (p *progressReporter) Start() {
 	p.t = htime.Now()
 }
 
+// allSites will range over all sites in the order of the sitesVersionsRoles matrix.
+// If include is not nil, it will be used to filter the sites.
 func (h *HugoSites) allSites(include func(s *Site) bool) iter.Seq[*Site] {
+	if include == nil {
+		include = func(s *Site) bool {
+			return true
+		}
+	}
 	return func(yield func(s *Site) bool) {
 		for _, v := range h.sitesVersionsRoles {
 			for _, r := range v {
 				for _, s := range r {
-					if include != nil && !include(s) {
+					if !include(s) {
 						continue
 					}
 					if !yield(s) {
@@ -155,6 +181,31 @@ func (h *HugoSites) allSites(include func(s *Site) bool) iter.Seq[*Site] {
 	}
 }
 
+// allSitesInterface is the same as allSites but returns page.Site, which is used in some places where we don't want to expose the full *Site type.
+// If include is not nil, it will be used to filter the sites.
+func (h *HugoSites) allSitesInterface(include func(s page.Site) bool) iter.Seq[page.Site] {
+	if include == nil {
+		include = func(s page.Site) bool {
+			return true
+		}
+	}
+	return func(yield func(s page.Site) bool) {
+		for _, v := range h.sitesVersionsRoles {
+			for _, r := range v {
+				for _, s := range r {
+					if !include(s) {
+						continue
+					}
+					// Site() returns a wrapped version of the site that only exposes the page.Site interface.
+					if !yield(s.Site()) {
+						return
+					}
+				}
+			}
+		}
+	}
+}
+
 // allSiteLanguages will range over the first site in each language that's not skipped.
 func (h *HugoSites) allSiteLanguages(include func(s *Site) bool) iter.Seq[*Site] {
 	return func(yield func(s *Site) bool) {
@@ -440,10 +491,6 @@ func (h *HugoSites) filterAndJoinErrors(errs []error) error {
 	return errors.Join(errs...)
 }
 
-func (h *HugoSites) isMultilingual() bool {
-	return len(h.Sites) > 1
-}
-
 // TODO(bep) consolidate
 func (h *HugoSites) LanguageSet() map[string]int {
 	set := make(map[string]int)
@@ -499,9 +546,15 @@ func (h *HugoSites) GetContentPage(filename string) page.Page {
 
 func (h *HugoSites) loadGitInfo() error {
 	if h.Configs.Base.EnableGitInfo {
-		gi, err := newGitInfo(h.Deps)
+		cfg := gitInfoConfig{
+			Deps:         h.Deps,
+			Modules:      h.Configs.Modules,
+			GitInfoCache: h.Configs.FileCaches.ModuleGitInfoCache(),
+			Logger:       h.Log,
+		}
+		gi, err := newGitInfo(cfg)
 		if err != nil {
-			h.Log.Errorln("Failed to read Git log:", err)
+			return err
 		} else {
 			h.gitInfo = gi
 		}
