@@ -506,7 +506,7 @@ func (s *IntegrationTestBuilder) ImageHelper(filename string) *IntegrationTestIm
 	fs := s.fs.WorkingDirReadOnly
 	b, err := afero.ReadFile(fs, filename)
 	s.Assert(err, qt.IsNil)
-	conf, format, err := s.H.ResourceSpec.Imaging.Codec.DecodeConfig(bytes.NewReader(b))
+	conf, format, err := s.H.ResourceSpec.Imaging.Codec.DecodeConfig(0, bytes.NewReader(b))
 	s.Assert(err, qt.IsNil)
 	img, err := s.H.ResourceSpec.Imaging.Codec.Decode(bytes.NewReader(b))
 	s.Assert(err, qt.IsNil)
@@ -879,12 +879,18 @@ func (s *IntegrationTestBuilder) initBuilder() error {
 			w = &s.logBuff
 		}
 
+		var logHookLast func(e *logg.Entry) error
+		if s.Cfg.PanicOnWarning {
+			logHookLast = loggers.PanicOnWarningHook
+		}
+
 		logger := loggers.New(
 			loggers.Options{
 				StdOut:        w,
 				StdErr:        w,
 				Level:         s.Cfg.LogLevel,
 				DistinctLevel: logg.LevelWarn,
+				HandlerPost:   logHookLast,
 			},
 		)
 
@@ -1143,6 +1149,9 @@ type IntegrationTestConfig struct {
 	// The log level to use.
 	LogLevel logg.Level
 
+	// Whether to panic on warnings.
+	PanicOnWarning bool
+
 	// Whether it needs the real file system (e.g. for js.Build tests).
 	NeedsOsFS bool
 
