@@ -18,6 +18,7 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"maps"
 	"mime"
 	"net/url"
 	"os"
@@ -32,13 +33,13 @@ import (
 	"github.com/bep/logg"
 	"github.com/gohugoio/go-radix"
 	"github.com/gohugoio/hugo/cache/dynacache"
+	"github.com/gohugoio/hugo/common/hmaps"
 	"github.com/gohugoio/hugo/common/hstore"
 	"github.com/gohugoio/hugo/common/hsync"
 	"github.com/gohugoio/hugo/common/htime"
 	"github.com/gohugoio/hugo/common/hugio"
 	"github.com/gohugoio/hugo/common/hugo"
 	"github.com/gohugoio/hugo/common/loggers"
-	"github.com/gohugoio/hugo/common/maps"
 	"github.com/gohugoio/hugo/common/para"
 	"github.com/gohugoio/hugo/common/types"
 	"github.com/gohugoio/hugo/config"
@@ -55,8 +56,6 @@ import (
 	"github.com/gohugoio/hugo/modules"
 	"github.com/gohugoio/hugo/resources"
 
-	xmaps "maps"
-
 	"github.com/gohugoio/hugo/tpl/tplimpl"
 	"github.com/gohugoio/hugo/tpl/tplimplinit"
 
@@ -202,6 +201,15 @@ func NewHugoSites(cfg deps.DepsCfg) (*HugoSites, error) {
 	rolesSorted := cfg.Configs.Base.Roles.Config.Sorted
 	versionsSorted := cfg.Configs.Base.Versions.Config.Sorted
 
+	var (
+		poolSizeKatex = 2
+		poolSizeWebP  = 1
+	)
+	if n := config.GetNumWorkerMultiplier(); n > 1 {
+		poolSizeKatex = min(n, 8)
+		poolSizeWebP = max(2, n/2)
+	}
+
 	var logger loggers.Logger
 	if cfg.TestLogger != nil {
 		logger = cfg.TestLogger
@@ -262,15 +270,14 @@ func NewHugoSites(cfg deps.DepsCfg) (*HugoSites, error) {
 			warpc.Options{
 				CompilationCacheDir: compilationCacheDir,
 
-				// Katex is relatively slow.
-				PoolSize: 8,
+				PoolSize: poolSizeKatex,
 				Infof:    logger.InfoCommand("katex").Logf,
 				Warnf:    logger.WarnCommand("katex").Logf,
 			},
 			// WebP options.
 			warpc.Options{
 				CompilationCacheDir: compilationCacheDir,
-				PoolSize:            1,
+				PoolSize:            poolSizeWebP,
 				Memory:              384, // 384 MiB (4096 MiB Max)
 				Infof:               logger.InfoCommand("webp").Logf,
 				Warnf:               logger.WarnCommand("webp").Logf,
@@ -478,7 +485,7 @@ func newHugoSites(
 			dynacache.OptionsPartition{Weight: 10, ClearWhen: dynacache.ClearOnRebuild},
 		),
 		cacheContentSource:      dynacache.GetOrCreatePartition[uint64, *resources.StaleValue[[]byte]](d.MemCache, "/cont/src", dynacache.OptionsPartition{Weight: 70, ClearWhen: dynacache.ClearOnChange}),
-		translationKeyPages:     maps.NewSliceCache[page.Page](),
+		translationKeyPages:     hmaps.NewSliceCache[page.Page](),
 		currentSite:             first[0],
 		skipRebuildForFilenames: make(map[string]bool),
 		init:                    &hugoSitesInit{},
@@ -510,7 +517,22 @@ func newHugoSites(
 		dependencies = append(dependencies, depFromMod(m))
 	}
 
-	h.hugoInfo = hugo.NewInfo(h.Configs.GetFirstLanguageConfig(), dependencies)
+	// Create providers that avoid naming conflicts with HugoSites fields.
+	sp := hugoSitesSitesProvider{h: h}
+
+	opts := page.HugoInfoOptions{
+		Conf:                      h.Configs.GetFirstLanguageConfig(),
+		HugoInfoHugoSitesProvider: sp,
+		Deps:                      dependencies,
+	}
+
+	if bi := hugo.GetBuildInfo(); bi != nil {
+		opts.CommitHash = bi.Revision
+		opts.BuildDate = bi.RevisionTime
+		opts.GoVersion = bi.GoVersion
+	}
+
+	h.hugoInfo = page.NewHugoInfo(opts)
 
 	var prototype *deps.Deps
 
@@ -620,13 +642,18 @@ func (s *Site) LanguageCode() string {
 	return s.Language().LanguageCode()
 }
 
-// Returns all Sites for all languages.
+// Returns all sites for all dimensions.
+// Deprecated: Use hugo.Sites instead.
 func (s *Site) Sites() page.Sites {
-	sites := make(page.Sites, len(s.h.Sites))
-	for i, s := range s.h.Sites {
-		sites[i] = s.Site()
-	}
-	return sites
+	s.h.printSiteSitesDeprecationInit.Do(func() {
+		hugo.Deprecate(".Site.Sites and .Page.Sites", "Use hugo.Sites instead.", "v0.156.0")
+	})
+	return slices.Collect(s.h.allSitesInterface(nil))
+}
+
+// IsDefault reports whether this site is the default across all dimensions.
+func (s *Site) IsDefault() bool {
+	return s.siteLanguageVersionRole.isDefault()
 }
 
 // Returns Site currently rendering.
@@ -641,13 +668,7 @@ func (s *Site) MainSections() []string {
 }
 
 // Returns a struct with some information about the build.
-func (s *Site) Hugo() hugo.HugoInfo {
-	if s.h == nil {
-		panic("site: hugo: h not initialized")
-	}
-	if s.h.hugoInfo.Environment == "" {
-		panic("site: hugo: hugoInfo not initialized")
-	}
+func (s *Site) Hugo() page.HugoInfo {
 	return s.h.hugoInfo
 }
 
@@ -656,62 +677,37 @@ func (s *Site) BaseURL() string {
 	return s.conf.C.BaseURL.WithPath
 }
 
-// Deprecated: Use .Site.Lastmod instead.
-func (s *Site) LastChange() time.Time {
-	s.CheckReady()
-	hugo.Deprecate(".Site.LastChange", "Use .Site.Lastmod instead.", "v0.123.0")
-	return s.lastmod
-}
-
 // Returns the last modification date of the content.
 func (s *Site) Lastmod() time.Time {
 	return s.lastmod
 }
 
 // Returns the Params configured for this site.
-func (s *Site) Params() maps.Params {
+func (s *Site) Params() hmaps.Params {
 	return s.conf.Params
 }
 
-// Deprecated: Use taxonomies instead.
-func (s *Site) Author() map[string]any {
-	if len(s.conf.Author) != 0 {
-		hugo.Deprecate(".Site.Author", "Implement taxonomy 'author' or use .Site.Params.Author instead.", "v0.124.0")
-	}
-	return s.conf.Author
-}
-
-// Deprecated: Use taxonomies instead.
-func (s *Site) Authors() page.AuthorList {
-	hugo.Deprecate(".Site.Authors", "Implement taxonomy 'authors' or use .Site.Params.Author instead.", "v0.124.0")
-	return page.AuthorList{}
-}
-
-// Deprecated: Use .Site.Params instead.
-func (s *Site) Social() map[string]string {
-	hugo.Deprecate(".Site.Social", "Implement taxonomy 'social' or use .Site.Params.Social instead.", "v0.124.0")
-	return s.conf.Social
-}
-
 func (s *Site) Param(key any) (any, error) {
 	return resource.Param(s, nil, key)
 }
 
 // Returns a map of all the data inside /data.
+// Deprecated: Use hugo.Data instead.
 func (s *Site) Data() map[string]any {
+	s.h.printSiteDataDeprecationInit.Do(func() {
+		hugo.Deprecate(".Site.Data", "Use hugo.Data instead.", "v0.156.0")
+	})
 	return s.h.Data()
 }
 
+// Deprecated: See https://discourse.gohugo.io/t/56732.
 func (s *Site) BuildDrafts() bool {
+	s.h.printSiteBuildDraftsDeprecationInit.Do(func() {
+		hugo.Deprecate(".Site.BuildDrafts", "See https://discourse.gohugo.io/t/56732.", "v0.156.0")
+	})
 	return s.conf.BuildDrafts
 }
 
-// Deprecated: Use hugo.IsMultilingual instead.
-func (s *Site) IsMultiLingual() bool {
-	hugo.Deprecate(".Site.IsMultiLingual", "Use hugo.IsMultilingual instead.", "v0.124.0")
-	return s.h.isMultilingual()
-}
-
 func (s *Site) LanguagePrefix() string {
 	prefix := s.GetLanguagePrefix()
 	if prefix == "" {
@@ -766,7 +762,11 @@ func (s *Site) RegularPages() page.Pages {
 }
 
 // AllPages returns all pages for all sites.
+// Deprecated: See https://discourse.gohugo.io/t/56732.
 func (s *Site) AllPages() page.Pages {
+	s.h.printSiteAllPagesDeprecationInit.Do(func() {
+		hugo.Deprecate(".Site.AllPages", "See https://discourse.gohugo.io/t/56732.", "v0.156.0")
+	})
 	s.CheckReady()
 	return s.h.Pages()
 }
@@ -987,7 +987,11 @@ func (s *Site) Language() *langs.Language {
 	return s.language
 }
 
+// Deprecated: See https://discourse.gohugo.io/t/56732.
 func (s *Site) Languages() langs.Languages {
+	s.h.printSiteLanguagesDeprecationInit.Do(func() {
+		hugo.Deprecate(".Site.Languages", "See https://discourse.gohugo.io/t/56732.", "v0.156.0")
+	})
 	return s.h.Configs.Languages
 }
 
@@ -1140,7 +1144,7 @@ func (w *WhatChanged) Changes() []identity.Identity {
 	if w == nil || w.ids == nil {
 		return nil
 	}
-	return slices.Collect(xmaps.Keys(w.ids))
+	return slices.Collect(maps.Keys(w.ids))
 }
 
 func (w *WhatChanged) Drain() []identity.Identity {
@@ -1399,8 +1403,12 @@ func (s *Site) assembleMenus() (navigation.Menus, error) {
 
 	// add menu entries from config to flat hash
 	for name, menu := range s.conf.Menus.Config {
-		for _, me := range menu {
-			if types.IsNil(me.Page) && me.PageRef != "" {
+		for _, x := range menu {
+			// Shallow copy the menu entry, so we can set the URL and page without modifying the config.
+			c := *x
+			me := &c
+
+			if me.PageRef != "" {
 				// Try to resolve the page.
 				me.Page, _ = s.getPage(nil, me.PageRef)
 			}
@@ -1753,21 +1761,6 @@ func (s *Site) render(ctx *siteRenderContext) (err error) {
 		return err
 	}
 
-	if ctx.outIdx == 0 && s.h.buildCounter.Load() == 0 {
-		// Note that even if disableAliases is set, the aliases themselves are
-		// preserved on page. The motivation with this is to be able to generate
-		// 301 redirects in a .htaccess file and similar using a custom output format.
-		if !s.conf.DisableAliases {
-			// Aliases must be rendered before pages.
-			// Some sites, Hugo docs included, have faulty alias definitions that point
-			// to itself or another real page. These will be overwritten in the next
-			// step.
-			if err = s.renderAliases(); err != nil {
-				return
-			}
-		}
-	}
-
 	if err = s.renderPages(ctx); err != nil {
 		return
 	}
