@@ -30,8 +30,10 @@ import (
 	"time"
 
 	"github.com/gohugoio/hugo/common/collections"
+	"github.com/gohugoio/hugo/common/hashing"
 	"github.com/gohugoio/hugo/common/herrors"
 	"github.com/gohugoio/hugo/common/hexec"
+	"github.com/gohugoio/hugo/common/hugio"
 	"github.com/gohugoio/hugo/common/loggers"
 	"github.com/gohugoio/hugo/config"
 
@@ -45,8 +47,6 @@ import (
 
 	"golang.org/x/mod/module"
 
-	"github.com/gohugoio/hugo/common/hugio"
-
 	"github.com/spf13/afero"
 )
 
@@ -440,16 +440,36 @@ func isProbablyModule(path string) bool {
 }
 
 func (c *Client) downloadModuleVersion(path, version string) (*goModule, error) {
-	args := []string{"mod", "download", "-json", fmt.Sprintf("%s@%s", path, version)}
-	b := &bytes.Buffer{}
+	// If it's already cached, use it.
+	const keyPrefix = "downloadmoduleversion_"
+	cacheKey := keyPrefix + hashing.XxHashFromStringHexEncoded(c.ccfg.CacheDir, path, version) + ".json"
+	if b, _ := c.ccfg.ModuleQueriesCache.GetBytes(cacheKey); len(b) > 0 {
+		var cm goModule
+		if err := json.Unmarshal(b, &cm); err == nil && cm.Dir != "" {
+			if c.isDirNonEmpty(cm.Dir) {
+				return &cm, nil
+			}
+		}
+	}
 
+	// No valid cache, need to query.
+	args := []string{"mod", "download", "-json", fmt.Sprintf("%s@%s", path, version)}
+
+	b := &bytes.Buffer{}
 	err := c.runGo(context.Background(), b, args...)
 	if err != nil {
+		// The -json flag makes Go output error details as JSON to stdout
+		// even on failure. Try to extract the error message from the JSON output.
+		if jsonErr := extractGoModDownloadError(b.Bytes()); jsonErr != "" {
+			return nil, fmt.Errorf("failed to download module %s@%s: %s: %s", path, version, err, jsonErr)
+		}
 		return nil, fmt.Errorf("failed to download module %s@%s: %w", path, version, err)
 	}
 
+	jsonResult := b.Bytes()
+
 	m := &goModule{}
-	if err := json.NewDecoder(b).Decode(m); err != nil {
+	if err := json.NewDecoder(bytes.NewReader(jsonResult)).Decode(m); err != nil {
 		return nil, fmt.Errorf("failed to decode module download result: %w", err)
 	}
 
@@ -457,9 +477,26 @@ func (c *Client) downloadModuleVersion(path, version string) (*goModule, error)
 		return nil, errors.New(m.Error.Err)
 	}
 
+	// Cache the successful result if it has a Dir field.
+	if m.Dir != "" {
+		_ = c.ccfg.ModuleQueriesCache.SetBytes(cacheKey, jsonResult)
+	}
+
 	return m, nil
 }
 
+// isDirNonEmpty returns true if dir exists and contains at least one file or subdirectory.
+func (c *Client) isDirNonEmpty(dir string) bool {
+	f, err := c.fs.Open(dir)
+	if err != nil {
+		return false
+	}
+	defer f.Close()
+	// Read just one entry to check if directory is non-empty.
+	_, err = f.Readdirnames(1)
+	return err == nil
+}
+
 func (c *Client) listGoMods() (goModules, error) {
 	if c.GoModulesFilename == "" || !c.moduleConfig.hasModuleImport() {
 		return nil, nil
@@ -527,6 +564,26 @@ func (c *Client) listGoMods() (goModules, error) {
 		if m.Dir == "" {
 			modulesToDownload = append(modulesToDownload, fmt.Sprintf("%s@%s", m.Path, m.Version))
 		}
+
+		// See https://github.com/golang/go/issues/67363
+		// Origin isn't always set.
+		if m.Origin == nil && m.GoMod != "" {
+			// There's sometimes an Info field with a JSON filename with this info, but that is also not always set.
+			// But we seem to always get the go.mod filename, so we can determine the info filename from that,
+			// just replace the .mod suffix with .info.
+			infoFilename := strings.TrimSuffix(m.GoMod, ".mod") + ".info"
+			// JSON on the form {"Version":"v0.0.0-20260225095909-668663b54d09","Time":"2026-02-25T09:59:09Z","Origin":{"VCS":"git","URL":"https://github.com/bep/hugo-mod-testing-content","Hash":"668663b54d0937df05185d144765d13c3ffda489"}}
+			if b, err := afero.ReadFile(c.fs, infoFilename); err == nil {
+				var info struct {
+					Version string
+					Time    time.Time
+					Origin  *goModuleOrigin
+				}
+				if err := json.Unmarshal(b, &info); err == nil {
+					m.Origin = info.Origin
+				}
+			}
+		}
 	}
 
 	if len(modulesToDownload) > 0 {
@@ -865,8 +922,15 @@ type ClientConfig struct {
 
 	Exec *hexec.Exec
 
-	CacheDir     string // Module cache
-	ModuleConfig Config
+	CacheDir           string // Module cache
+	ModuleQueriesCache ModuleQueriesCache
+	ModuleConfig       Config
+}
+
+// ModuleQueriesCache is a cache for module version queries.
+type ModuleQueriesCache interface {
+	GetBytes(id string) ([]byte, error)
+	SetBytes(id string, data []byte) error
 }
 
 func (c ClientConfig) shouldIgnoreVendor(path string) bool {
@@ -920,12 +984,33 @@ type goModule struct {
 	Dir      string         // directory holding files for this module, if any
 	GoMod    string         // path to go.mod file for this module, if any
 	Error    *goModuleError // error loading module
+	Origin   *goModuleOrigin
+}
+
+type goModuleOrigin struct {
+	VCS    string // version control system, e.g. "git"
+	URL    string // repository URL, e.g. "https://github.com/bep/hugo-testing-git-versions"
+	Hash   string // commit hash
+	TagSum string
+	Ref    string // e.g. "refs/tags/v3.0.1"
 }
 
 type goModuleError struct {
 	Err string // the error itself
 }
 
+func extractGoModDownloadError(b []byte) string {
+	// go mod download -json outputs Error as a plain string,
+	// unlike go list -m -json which uses {"Err": "..."}.
+	var m struct {
+		Error string
+	}
+	if err := json.Unmarshal(b, &m); err == nil && m.Error != "" {
+		return m.Error
+	}
+	return ""
+}
+
 type goModules []*goModule
 
 type modSum struct {
